==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicator = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new ChaikinOscillatorIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return ChaikinOscillatorIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get shortPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.zk));
        }
        set shortPeriod(a) {
            this.h(ChaikinOscillatorIndicator.zk, a);
        }
        y6() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.zj));
        }
        set longPeriod(a) {
            this.h(ChaikinOscillatorIndicator.zj, a);
        }
        y3() {
            return this.longPeriod;
        }
    }
    ChaikinOscillatorIndicator.$t = /*@__PURE__*/ markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zi(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.zj = /*@__PURE__*/ StrategyBasedIndicator.ze(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicator = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
        bj() {
            return new ChaikinOscillatorIndicator();
        }
        get_abq() {
            return new ChaikinOscillatorIndicatorStrategy();
        }
        get abq() {
            return this.get_abq();
        }
        get_ab3() {
            return ChaikinOscillatorIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
        get shortPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.acc));
        }
        set shortPeriod(a) {
            this.h(ChaikinOscillatorIndicator.acc, a);
        }
        aby() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.acb));
        }
        set longPeriod(a) {
            this.h(ChaikinOscillatorIndicator.acb, a);
        }
        abv() {
            return this.longPeriod;
        }
    }
    ChaikinOscillatorIndicator.$t = /*@__PURE__*/ markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.acc = /*@__PURE__*/ StrategyBasedIndicator.aca(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.acb = /*@__PURE__*/ StrategyBasedIndicator.ab6(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
})();
